Remove unless there is a comment explaining why the variable is needed. If so, add
`# robocop:off=unused-argument`. If a FOR loop requires a variable but it is
intentionally unused, use the variable name `${_}`.
